@@ -37,7 +37,8 @@ def odd(sq: IteratorOrIterable) -> tp.Iterator[T]:
         return
 
 
-def count(sq: IteratorOrIterable, start: tp.Optional[int] = None, step: int = 1) -> tp.Iterator[int]:
+def count(sq: IteratorOrIterable, start: tp.Optional[int] = None, step: int = 1,
+          start_at: tp.Optional[int] = None) -> tp.Iterator[int]:
     """
     Return a sequence of integers, for each entry in the sequence with provided step.
 
@@ -46,11 +47,13 @@ def count(sq: IteratorOrIterable, start: tp.Optional[int] = None, step: int = 1)
     >>> (i for i, x in enumerate(sq, start=start_at))
 
     :param sq: sequence to enumerate
-    :param start: alias for start_at. Prefer it in regards to start_at
+    :param start: alias for start_at. Prefer it in regards to start_at. Default is 0
     :param step: number to add to internal counter after each element
     :return: an iterator of subsequent integers
     """
-    num = start
+    if start_at:
+        start = start_at
+    num = start or 0
     for _ in sq:
         yield num
         num += step
@@ -93,11 +96,11 @@ def is_instance(classes: tp.Union[tp.Tuple[type, ...], type]) -> tp.Callable[[ob
 def other_sequence_no_longer_than(base_sequence: IteratorOrIterable,
                                   other_sequence: IteratorOrIterable[T]) -> tp.Iterator[T]:
     """
-    Return every item in other_sequence, but limit it's length to that of base_sequence.
+    Return every item in other_sequence, but limit it's p_len to that of base_sequence.
 
     If other_sequence is shorter than base_sequence, the shorter one will be returned.
 
-    :param base_sequence: sequence whose length should be taken
+    :param base_sequence: sequence whose p_len should be taken
     :param other_sequence: sequence to output values from
     """
     base_sequence, other_sequence = iter(base_sequence), iter(other_sequence)
@@ -216,6 +219,33 @@ def n_th(iterator: IteratorOrIterable, n: int = 0) -> T:
         raise IndexError('Iterable was too short')
 
 
+def enumerate(iterator: IteratorOrIterable, start: int = 0) -> tp.Iterator[tp.Tuple]:
+    """
+    An enumerate that talks pretty with lists of tuples. Consider
+
+    >>> a = [(1, 2), (3, 4), (5, 6)]
+    >>> for i, b in enumerate(a):
+    >>>     c, d = b
+    >>>     ...
+
+    This function allows you just to write:
+    >>> for i, c, d in enumerate(a):
+    >>>     ...
+
+    Note that elements in your iterable must be either a list of a tuple for that to work,
+    or need to be able to be coerced to a tuple. Otherwise, TypeError will be thrown.
+
+    :raise TypeError: could not coerce the elements in your iterable to a tuple
+    """
+    i = start
+    for row in iterator:
+        if isinstance(row, tuple):
+            yield (i, ) + row
+        else:
+            yield (i,) + tuple(row)
+        i += 1
+
+
 def take_n(iterator: IteratorOrIterable, n: int, skip: int = 0) -> tp.List[T]:
     """
     Take (first) n elements of an iterator, or the entire iterator, whichever comes first
@@ -223,7 +253,7 @@ def take_n(iterator: IteratorOrIterable, n: int, skip: int = 0) -> tp.List[T]:
     :param iterator: iterator to take from
     :param n: amount of elements to take
     :param skip: elements from the start to skip
-    :return: list of length n (or shorter)
+    :return: list of p_len n (or shorter)
     """
     iterator = iter(iterator)
     for i in range(skip):
