@@ -1,30 +1,30 @@
 from .dictionaries import DictObject, apply_dict_object, DictionaryView, TwoWayDictionary, \
-    DirtyDict, KeyAwareDefaultDict
+    DirtyDict, KeyAwareDefaultDict, ExpiringEntryDict, SelfCleaningDefaultDict
 from .hashable_objects import HashableWrapper
 from .immutable import Immutable, frozendict
-from .singleton import Singleton, SingletonWithRegardsTo
-from .structures import SetHeap, OmniHashableMixin, TimeBasedHeap, Heap, ReprableObject
 from .proxy import Proxy
-from .typednamedtuple import typednamedtuple
 from .ranking import Ranking
+from .singleton import Singleton, SingletonWithRegardsTo
 from .sorted_list import SortedList, SliceableDeque
+from .mixins import OmniHashableMixin, ReprableMixin
+from .heaps import Heap, SetHeap, TimeBasedHeap, TimeBasedSetHeap
+from .typednamedtuple import typednamedtuple
 
 __all__ = [
     'KeyAwareDefaultDict',
     'Proxy',
-    'ReprableObject',
+    'ReprableMixin',
     'DirtyDict',
     'SortedList',
+    'SelfCleaningDefaultDict',
     'SliceableDeque',
     'Ranking',
+    'ExpiringEntryDict',
     'TwoWayDictionary',
     'typednamedtuple',
     'HashableWrapper',
-    'Heap',
-    'SetHeap',
     'DictionaryView',
     'frozendict',
-    'TimeBasedHeap',
     'OmniHashableMixin',
     'Singleton',
     'SingletonWithRegardsTo',
